@@ -7,6 +7,7 @@ import os
 import re
 import datetime
 import pathlib
+import hashlib
 
 
 def fix_block_encoding_errors(block):
@@ -200,6 +201,20 @@ def get_disk_utilization(prev_ticks, ticks, itv):
     return util_percent
 
 
+def get_array_hash(d):
+    h = hashlib.sha1()
+    if isinstance(d, list):
+        for v in d:
+            h.update(str(v).encode())
+    elif isinstance(d, dict):
+        for k, v in d.items():
+            h.update(str(k).encode())
+            h.update(str(v).encode())
+    else:
+        raise RuntimeError("Unsupported array type: %s" % type(d))
+    return h.hexdigest()
+
+
 class Logger:
     def __init__(self, to_console=True, file=None):
         self._to_console = to_console
